@@ -28,6 +28,8 @@ from annofabcli.common.typing import InputDataSize
 
 logger = logging.getLogger(__name__)
 
+DEFAULT_CSV_FORMAT = {"encoding": "utf_8_sig", "index": False}
+
 
 def build_annofabapi_resource_and_login(args: argparse.Namespace) -> annofabapi.Resource:
     """
@@ -78,7 +80,12 @@ def add_parser(
     """
     parents = [create_parent_parser()] if is_subcommand else []
     parser = subparsers.add_parser(
-        command_name, parents=parents, description=description, help=command_help, epilog=epilog
+        command_name,
+        parents=parents,
+        description=description,
+        help=command_help,
+        epilog=epilog,
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     parser.set_defaults(command_help=parser.print_help)
     return parser
@@ -154,7 +161,7 @@ def get_csv_format_from_args(target: Optional[str] = None) -> Dict[str, Any]:
     Default: {"encoding": "utf_8_sig", "index": False}
 
     """
-    csv_format = {"encoding": "utf_8_sig", "index": False}
+    csv_format = DEFAULT_CSV_FORMAT.copy()
     if target is not None:
         arg_csv_format = get_json_from_args(target)
         csv_format.update(arg_csv_format)
@@ -423,6 +430,31 @@ class ArgumentParser:
         self.parser.add_argument("-q", "--query", type=str, help=help_message)
 
 
+class AbstracCommandCinfirmInterface(abc.ABC):
+    """
+    コマンドライン上でpromptを表示するときのインターフェイズ
+    """
+
+    def __init__(self, all_yes: bool = False):
+        self.all_yes = all_yes
+
+    def confirm_processing(self, confirm_message: str) -> bool:
+        """
+        `all_yes`属性を見て、処理するかどうかユーザに問い合わせる。
+        "ALL"が入力されたら、`all_yes`属性をTrueにする
+
+        Returns:
+            True: Yes, False: No
+
+        """
+        if self.all_yes:
+            return True
+        yes, all_yes = prompt_yesnoall(confirm_message)
+        if all_yes:
+            self.all_yes = True
+        return yes
+
+
 class AbstractCommandLineInterface(abc.ABC):
     """
     CLI用の抽象クラス
@@ -432,7 +464,7 @@ class AbstractCommandLineInterface(abc.ABC):
     service: annofabapi.Resource
 
     #: AnnofabApiFacadeインスタンス
-    facade: annofabcli.AnnofabApiFacade
+    facade: AnnofabApiFacade
 
     #: Trueならば、処理中に現れる問い合わせに対して、常に'yes'と回答したものとして処理する。
     all_yes: bool = False
